@@ -26,6 +26,7 @@
 #include "misc.h"
 #include "lib-config/iconfig.h"
 #include "settings.h"
+#include "iregex.h"
 
 #include "servers.h"
 #include "channels.h"
@@ -101,11 +102,7 @@ static void hilight_destroy(HILIGHT_REC *rec)
 {
 	g_return_if_fail(rec != NULL);
 
-#ifdef USE_GREGEX
-	if (rec->preg != NULL) g_regex_unref(rec->preg);
-#else
-	if (rec->regexp_compiled) regfree(&rec->preg);
-#endif
+	if (rec->preg != NULL) i_regex_unref(rec->preg);
 	if (rec->channels != NULL) g_strfreev(rec->channels);
 	g_free_not_null(rec->color);
 	g_free_not_null(rec->act_color);
@@ -123,19 +120,10 @@ static void hilights_destroy_all(void)
 
 static void hilight_init_rec(HILIGHT_REC *rec)
 {
-#ifdef USE_GREGEX
 	if (rec->preg != NULL)
-		g_regex_unref(rec->preg);
+		i_regex_unref(rec->preg);
 
-	rec->preg = g_regex_new(rec->text, G_REGEX_OPTIMIZE | G_REGEX_RAW | G_REGEX_CASELESS, 0, NULL);
-#else
-	if (rec->regexp_compiled) regfree(&rec->preg);
-	if (!rec->regexp)
-		rec->regexp_compiled = FALSE;
-	else
-		rec->regexp_compiled = regcomp(&rec->preg, rec->text,
-				rec->case_sensitive ? REG_EXTENDED : (REG_EXTENDED|REG_ICASE)) == 0;
-#endif
+	rec->preg = i_regex_new(rec->text, G_REGEX_OPTIMIZE | G_REGEX_CASELESS, 0, NULL);
 }
 
 void hilight_create(HILIGHT_REC *rec)
@@ -208,30 +196,15 @@ static gboolean hilight_match_text(HILIGHT_REC *rec, const char *text,
 	gboolean ret = FALSE;
 
 	if (rec->regexp) {
-#ifdef USE_GREGEX
 		if (rec->preg != NULL) {
-			GMatchInfo *match;
+			MatchInfo *match;
+			i_regex_match(rec->preg, text, 0, &match);
 
-			g_regex_match (rec->preg, text, 0, &match);
+			if (i_match_info_matches(match))
+				ret = i_match_info_fetch_pos(match, 0, match_beg, match_end);
 
-			if (g_match_info_matches(match))
-				ret = g_match_info_fetch_pos(match, 0, match_beg, match_end);
-
-			g_match_info_free(match);
+			i_match_info_free(match);
 		}
-#else
-		regmatch_t rmatch[1];
-
-		if (rec->regexp_compiled &&
-			regexec(&rec->preg, text, 1, rmatch, 0) == 0) {
-			if (rmatch[0].rm_so > 0 &&
-				match_beg != NULL && match_end != NULL) {
-				*match_beg = rmatch[0].rm_so;
-				*match_end = rmatch[0].rm_eo;
-			}
-			ret = TRUE;
-		}
-#endif
 	} else {
 		char *match;
 
@@ -400,34 +373,29 @@ static void sig_print_text(TEXT_DEST_REC *dest, const char *text,
 		char *middle;
 		int pos, color_pos, color_len;
 
-		tmp = g_string_new(NULL);
-
 		/* start of the line */
 		pos = strip_real_length(text, hilight_start, NULL, NULL);
-		g_string_append(tmp, text);
-		g_string_truncate(tmp, pos);
+		tmp = g_string_new_len(text, pos);
 
 		/* color */
 		g_string_append(tmp, color);
 
 		/* middle of the line, stripped */
-		middle = strip_codes(text+pos);
-		pos = tmp->len;
-		g_string_append(tmp, middle);
-		g_string_truncate(tmp, pos+hilight_len);
+		middle = strip_codes(text + pos);
+		g_string_append_len(tmp, middle, hilight_len);
 		g_free(middle);
 
 		/* end of the line */
 		pos = strip_real_length(text, hilight_end,
 					&color_pos, &color_len);
 		if (color_pos > 0)
-			g_string_append_len(tmp, text+color_pos, color_len);
+			g_string_append_len(tmp, text + color_pos, color_len);
                 else {
                         /* no colors in line, change back to default */
 			g_string_append_c(tmp, 4);
 			g_string_append_c(tmp, FORMAT_STYLE_DEFAULTS);
 		}
-		g_string_append(tmp, text+pos);
+		g_string_append(tmp, text + pos);
 
 		newstr = tmp->str;
 		g_string_free(tmp, FALSE);
@@ -532,13 +500,8 @@ static void hilight_print(int index, HILIGHT_REC *rec)
 	if (rec->case_sensitive) g_string_append(options, "-matchcase ");
 	if (rec->regexp) {
 		g_string_append(options, "-regexp ");
-#ifdef USE_GREGEX
 		if (rec->preg == NULL)
 			g_string_append(options, "[INVALID!] ");
-#else
-		if (!rec->regexp_compiled)
-			g_string_append(options, "[INVALID!] ");
-#endif
 	}
 
 	if (rec->priority != 0)
